@@ -390,3 +390,17 @@ gob_strdown (char *str)
 	return str;
 }
 
+char *
+make_me_type (const char *type, const char *alt)
+{
+	if (type == NULL)
+		return g_strdup (alt);
+	/* HACK!  just in case someone made this
+	 * work with 2.0.0 by using the TYPE
+	 * macro directly */
+	if ((strstr (type, "_TYPE_") != NULL ||
+	     strstr (type, "TYPE_") == type) &&
+	    strchr (type, ':') == NULL)
+		return g_strdup (type);
+	return make_pre_macro (type, "TYPE");
+}
